# react-test-context-provider

A function that allows you to specify context to pass to a child component (intended for testing only).

## Installation

This module is distributed via [npm][npm] which is bundled with [node][node] and should
be installed as one of your project's `devDependencies`:

```
npm install --save-dev react-test-context-provider
```

## Usage

```javascript
var getContextProvider = require('react-test-context-provider')
var reactElement = getContextProvider(<ComponentThatNeedsContext />, contextObject)
```

In this example, I'm using the [Jest](http://facebook.github.io/jest/) testing framework.

**Button.js**

```javascript
import React, {PropTypes} from 'react'
export default function Button({children}, {color}) {
  // function components receive context as the second argument
  return <button style={{background: color}}>{children}</button>
}
Button.propTypes = {children: PropTypes.any.isRequired}
Button.contextTypes = {color: PropTypes.string}
```

**Button.test.js**

```javascript
import React from 'react'
import renderer from 'react-test-renderer'
import getContextProvider from 'react-test-context-provider'
import Button from './Button'

test('styles the button with a background of the context color', () => {
  const component = renderer.create(
    getContextProvider(<Button>Click Me</Button>, {color: 'blue'})
  )
  const tree = component.toJSON()
  expect(tree).toMatchSnapshot()
})
```

## LICENSE

MIT

[npm]: https://www.npmjs.com/
[node]: https://nodejs.org
